
# (X): Leptons:

# (X): Lepton | Electron
_MASS_OF_ELECTRON_IN_GEV = 0.00051099895000
_LOWER_UNCERTAINTY_MASS_OF_ELECTRON_IN_GEV = 0.00000000000015
_UPPER_UNCERTAINTY_MASS_OF_ELECTRON_IN_GEV = 0.00000000000015

# (X): Lepton | Muon
_MASS_OF_MUON_IN_GEV = 0.1056583755
_LOWER_UNCERTAINTY_MASS_OF_MUON_IN_GEV = 0.0000000023
_UPPER_UNCERTAINTY_MASS_OF_MUON_IN_GEV = 0.0000000023

# (X): Lepton | Tau
_MASS_OF_TAU_IN_GEV = 1.77693
_LOWER_UNCERTAINTY_MASS_OF_TAU_IN_GEV = 0.00009
_UPPER_UNCERTAINTY_MASS_OF_TAU_IN_GEV = 0.00009

# (X): Baryons

# (X): Baryon | Proton
_MASS_OF_PROTON_IN_GEV = .93827208816
_LOWER_UNCERTAINTY_MASS_OF_PROTON_IN_GEV = 0.00000000029
_UPPER_UNCERTAINTY_MASS_OF_PROTON_IN_GEV = 0.00000000029
_MASS_OF_PROTON_SQUARED_IN_GEV_SQUARED = _MASS_OF_PROTON_IN_GEV *_MASS_OF_PROTON_IN_GEV

# (X): Couplings:

# (X): Coupling | QED
_ELECTROMAGNETIC_FINE_STRUCTURE_CONSTANT = (1. / 137.035999177)

# (X): Nuclear Experimentally-Derived Parameters:

# (X): Nuclear Experimentally-Derived Parameters | Electric Form Factor:
_ELECTRIC_FORM_FACTOR_CONSTANT = 0.710649

# (X): Nuclear Experimentally-Derived Parameters | Proton Magnetic Moment:
_PROTON_MAGNETIC_MOMENT = 2.79284734463